==> android-aihelp-aar-2.4.4-sources.jar: net/aihelp/ui/widget/AIHelpLoadingImageView.java <==
package net.aihelp.ui.widget;

import android.animation.LayoutTransition;
import android.app.Activity;
import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Bitmap;
import android.util.AttributeSet;
import android.view.Gravity;
import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;

//import com.bumptech.glide.Glide;
//import com.bumptech.glide.RequestBuilder;
//import com.bumptech.glide.load.engine.DiskCacheStrategy;
//import com.bumptech.glide.load.resource.bitmap.RoundedCorners;
//import com.bumptech.glide.request.RequestOptions;
//import com.bumptech.glide.request.target.SimpleTarget;
//import com.bumptech.glide.request.transition.Transition;

import net.aihelp.R;
import net.aihelp.core.ui.image.Picasso;
import net.aihelp.core.ui.image.TargetAdapter;
import net.aihelp.core.ui.loading.indicator.LoadingIndicatorView;
import net.aihelp.data.model.cs.ConversationMsg;
import net.aihelp.utils.TLog;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.appcompat.widget.AppCompatImageView;

public class AIHelpLoadingImageView extends FrameLayout {

    private AppCompatImageView imageView;
    private AppCompatImageView ivPlay;
    private View maskView;
    private LoadingIndicatorView loadingView;

    private boolean isVideo;

    private boolean isLoading;

    public boolean isLoading() {
        return isLoading;
    }

    public void setLoading(boolean loading) {
        isLoading = loading;
    }

    public AppCompatImageView getRealImageView() {
        return imageView;
    }

    public AIHelpLoadingImageView(@NonNull Context context) {
        super(context);
    }

    public AIHelpLoadingImageView(@NonNull Context context, @Nullable AttributeSet attrs) {
        super(context, attrs);
        getAttributes(context, attrs);
        init(context);
    }

    public AIHelpLoadingImageView(@NonNull Context context, @Nullable AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        getAttributes(context, attrs);
        init(context);
    }

    private void getAttributes(Context context, AttributeSet attrs) {
        TypedArray ta = context.getTheme().obtainStyledAttributes(attrs, R.styleable.aihelp_widget, 0, 0);
        isVideo = ta.getBoolean(R.styleable.aihelp_widget_aihelp_widget_is_video, false);
        ta.recycle();
    }

    private void init(Context context) {

        setLayoutTransition(new LayoutTransition());
        setBackground(getResources().getDrawable(R.drawable.aihelp_bg_uploading_mask));
        setForegroundGravity(Gravity.CENTER);

        View rootView = inflate(context, R.layout.aihelp_loading_image_view, this);
        imageView = rootView.findViewById(R.id.aihelp_image_view);
        ivPlay = rootView.findViewById(R.id.aihelp_iv_play);
        maskView = rootView.findViewById(R.id.aihelp_v_mask);
        loadingView = rootView.findViewById(R.id.aihelp_loading_view);
        updateLoadingStatus(true);
    }

    public void updateLoadingStatus(boolean showLoading) {
        maskView.setVisibility(showLoading ? VISIBLE : GONE);
        loadingView.setVisibility(showLoading ? VISIBLE : GONE);
        if (isVideo) {
            ivPlay.setVisibility(showLoading ? GONE : VISIBLE);
        }
        setLoading(showLoading);
    }

    public void loadIntoImageView(final Context context, final ConversationMsg conversationMsg) {
        if (context instanceof Activity && !((Activity) context).isFinishing()) {
            final String loadSource = isVideo ? conversationMsg.getVideoThumbnail() : conversationMsg.getMsgContent();

            // When user manually send images or videos, the message content will always be the image's or
            // the video thumbnail's absolute path.
            // In this case, the loading status should be reset by the msg SUCCESS status.
            if (conversationMsg.getMsgStatus() == ConversationMsg.STATUS_SUCCESS) {
                if (isVideo || !conversationMsg.isMessageFromServer()) {
                    updateLoadingStatus(false);
                }
            }

            if (conversationMsg.getImageSize() != null) {
                ViewGroup.LayoutParams rootLayoutParams = AIHelpLoadingImageView.this.getLayoutParams();
                ViewGroup.LayoutParams params = imageView.getLayoutParams();
                rootLayoutParams.width = params.width = conversationMsg.getImageSize()[0];
                rootLayoutParams.height = params.height = conversationMsg.getImageSize()[1];
                setLayoutParams(rootLayoutParams);
                imageView.setLayoutParams(params);
                Picasso.get().load(loadSource).fit().into(imageView);
                return;
            }

            Picasso.get().load(loadSource).into(new TargetAdapter() {
                @Override
                public void onBitmapLoaded(Bitmap resource, Picasso.LoadedFrom from) {
                    TLog.e("onBitmapLoaded " + resource.getWidth() + ", " + resource.getHeight() + ", " + from.name());

                    if (conversationMsg.getImageSize() == null) {
                        int[] size = new int[2];
                        ViewGroup.LayoutParams params = AIHelpLoadingImageView.this.getLayoutParams();

                        float scale = Math.max(resource.getWidth(), resource.getHeight()) / 700f;
                        if (scale < 1) scale = 1;

                        size[0] = params.width = Math.max(resource.getWidth() / (int) Math.ceil(scale), dip2px(getContext(), 50));
                        size[1] = params.height = Math.max(resource.getHeight() / (int) Math.ceil(scale), dip2px(getContext(), 50));

                        conversationMsg.setImageSize(size);
                        AIHelpLoadingImageView.this.setLayoutParams(params);
                    }

                    Picasso.get().load(loadSource).fit().into(imageView);

                    // As for the left cases, such as received images, history messages, etc,
                    // the msg content will always be http urls, just reset the loading status after the #into() finished.
                    updateLoadingStatus(false);
                }
            });

        }
    }

    public int dip2px(Context context, double dpValue) {
        float density = context.getResources().getDisplayMetrics().density;
        return (int) (dpValue * density + 0.5);
    }

    public void showPlayButton(boolean show) {
        ivPlay.setVisibility(show ? VISIBLE : GONE);
    }

}

==> android-aihelp-aar-3.1.7-sources.jar: net/aihelp/ui/widget/AIHelpLoadingImageView.java <==
package net.aihelp.ui.widget;

import android.animation.LayoutTransition;
import android.app.Activity;
import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Bitmap;
import android.util.AttributeSet;
import android.view.Gravity;
import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;

//import com.bumptech.glide.Glide;
//import com.bumptech.glide.RequestBuilder;
//import com.bumptech.glide.load.engine.DiskCacheStrategy;
//import com.bumptech.glide.load.resource.bitmap.RoundedCorners;
//import com.bumptech.glide.request.RequestOptions;
//import com.bumptech.glide.request.target.SimpleTarget;
//import com.bumptech.glide.request.transition.Transition;


import net.aihelp.core.ui.image.Picasso;
import net.aihelp.core.ui.image.TargetAdapter;
import net.aihelp.core.ui.loading.indicator.LoadingIndicatorView;
import net.aihelp.data.model.cs.ConversationMsg;
import net.aihelp.utils.DomainSupportHelper;
import net.aihelp.utils.ResResolver;
import net.aihelp.utils.TLog;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.appcompat.content.res.AppCompatResources;
import androidx.appcompat.widget.AppCompatImageView;

public class AIHelpLoadingImageView extends FrameLayout {

    private AppCompatImageView imageView;
    private AppCompatImageView ivPlay;
    private View maskView;
    private LoadingIndicatorView loadingView;

    private boolean isVideo;

    private boolean isLoading;

    public boolean isLoading() {
        return isLoading;
    }

    public void setLoading(boolean loading) {
        isLoading = loading;
    }

    public AppCompatImageView getRealImageView() {
        return imageView;
    }

    public AIHelpLoadingImageView(@NonNull Context context) {
        super(context);
    }

    public AIHelpLoadingImageView(@NonNull Context context, @Nullable AttributeSet attrs) {
        super(context, attrs);
        getAttributes(context, attrs);
        init(context);
    }

    public AIHelpLoadingImageView(@NonNull Context context, @Nullable AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        getAttributes(context, attrs);
        init(context);
    }

    private void getAttributes(Context context, AttributeSet attrs) {
        int[] styleable = ResResolver.getStyleable("aihelp_widget");
        if (styleable != null) {
            TypedArray ta = context.getTheme().obtainStyledAttributes(attrs, styleable, 0, 0);
            isVideo = ta.getBoolean(ResResolver.getStyleableFieldIndex("aihelp_widget",
                    "aihelp_widget_is_video"), false);
            ta.recycle();
        }
    }

    private void init(Context context) {

        setLayoutTransition(new LayoutTransition());
        setBackground(AppCompatResources.getDrawable(context, ResResolver.getDrawableId("aihelp_bg_uploading_mask")));
        setForegroundGravity(Gravity.CENTER);

        View rootView = inflate(context, ResResolver.getLayoutId("aihelp_loading_image_view"), this);
        imageView = rootView.findViewById(ResResolver.getViewId("aihelp_image_view"));
        ivPlay = rootView.findViewById(ResResolver.getViewId("aihelp_iv_play"));
        maskView = rootView.findViewById(ResResolver.getViewId("aihelp_v_mask"));
        loadingView = rootView.findViewById(ResResolver.getViewId("aihelp_loading_view"));
        updateLoadingStatus(true);
    }

    public void updateLoadingStatus(boolean showLoading) {
        maskView.setVisibility(showLoading ? VISIBLE : GONE);
        loadingView.setVisibility(showLoading ? VISIBLE : GONE);
        if (isVideo) {
            ivPlay.setVisibility(showLoading ? GONE : VISIBLE);
        }
        setLoading(showLoading);
    }

    public void loadIntoImageView(final Context context, final ConversationMsg conversationMsg) {
        if (context instanceof Activity && !((Activity) context).isFinishing()) {
            final String loadSource = DomainSupportHelper.correctDomain(
                    isVideo ? conversationMsg.getVideoThumbnail() : conversationMsg.getMsgContent()
            );

            // When user manually send images or videos, the message content will always be the image's or
            // the video thumbnail's absolute path.
            // In this case, the loading status should be reset by the msg SUCCESS status.
            if (conversationMsg.getMsgStatus() == ConversationMsg.STATUS_SUCCESS) {
                if (isVideo || !conversationMsg.isMessageFromServer()) {
                    updateLoadingStatus(false);
                }
            }

            if (conversationMsg.getImageSize() != null) {
                ViewGroup.LayoutParams rootLayoutParams = AIHelpLoadingImageView.this.getLayoutParams();
                ViewGroup.LayoutParams params = imageView.getLayoutParams();
                rootLayoutParams.width = params.width = conversationMsg.getImageSize()[0];
                rootLayoutParams.height = params.height = conversationMsg.getImageSize()[1];
                setLayoutParams(rootLayoutParams);
                imageView.setLayoutParams(params);
                Picasso.get().load(loadSource).fit().into(imageView);
                return;
            }

            Picasso.get().load(loadSource).into(new TargetAdapter() {
                @Override
                public void onBitmapLoaded(Bitmap resource, Picasso.LoadedFrom from) {
                    TLog.e("onBitmapLoaded " + resource.getWidth() + ", " + resource.getHeight() + ", " + from.name());

                    if (conversationMsg.getImageSize() == null) {
                        int[] size = new int[2];
                        ViewGroup.LayoutParams params = AIHelpLoadingImageView.this.getLayoutParams();

                        float scale = Math.max(resource.getWidth(), resource.getHeight()) / 700f;
                        if (scale < 1) scale = 1;

                        size[0] = params.width = Math.max(resource.getWidth() / (int) Math.ceil(scale), dip2px(getContext(), 50));
                        size[1] = params.height = Math.max(resource.getHeight() / (int) Math.ceil(scale), dip2px(getContext(), 50));

                        conversationMsg.setImageSize(size);
                        AIHelpLoadingImageView.this.setLayoutParams(params);
                    }

                    Picasso.get().load(loadSource).fit().into(imageView);

                    // As for the left cases, such as received images, history messages, etc,
                    // the msg content will always be http urls, just reset the loading status after the #into() finished.
                    updateLoadingStatus(false);
                }
            });

        }
    }

    public int dip2px(Context context, double dpValue) {
        float density = context.getResources().getDisplayMetrics().density;
        return (int) (dpValue * density + 0.5);
    }

    public void showPlayButton(boolean show) {
        ivPlay.setVisibility(show ? VISIBLE : GONE);
    }

}
